#container {
  position: absolute;
  height: 100%;
  width: 100%;
}
#node-selector {
  border: 1px solid black;
  position: absolute;
}
#node-inspector {
  border: 1px solid black;
  position: absolute;
}
#scenario {
  position: relative;
  height: 100%;
  width: 100%;
}
.pni-node-perldata-scalar {
  border: 1px solid black;
  position: absolute;
  display: block;
}
